<style lang="less">
@import "@/styles/table-common.less";
@import "@/styles/drawer-common.less";
@import "src/views/your/orderEvaluate-manage/orderEvaluateManage.less";
</style>
<template>
  <div class="search">
    <Card>
      <Row class="operation">
        <Button @click="init" icon="md-refresh">刷新</Button>
      </Row>
      <Alert show-icon v-show="openTip">
        已选择
        <span class="select-count">{{ selectList.length }}</span> 项
        <a class="select-clear" @click="clearSelectAll">清空</a>
      </Alert>
      <Table
        :loading="loading"
        border
        :columns="columns"
        :data="data"
        ref="table"
        sortable="custom"
        @on-sort-change="changeSort"
        @on-selection-change="changeSelect"
      ></Table>
      <Row type="flex" justify="end" class="page">
        <Page
          :current="searchForm.pageNumber"
          :total="total"
          :page-size="searchForm.pageSize"
          @on-change="changePage"
          @on-page-size-change="changePageSize"
          :page-size-opts="[10, 20, 50]"
          size="small"
          show-total
          show-elevator
          show-sizer
        ></Page>
      </Row>
    </Card>

    <!-- 编辑 -->
    <Modal
      :title="modalTitle"
      v-model="roleModalVisible"
      :mask-closable="false"
      :width="500"
    >
      <Form ref="carForm" :model="carForm" :label-width="80" :rules="carFormValidate">
        <FormItem label="品牌" prop="brand">
          <Input v-model="carForm.brand"/>
        </FormItem>
        <FormItem label="型号" prop="model">
          <Input v-model="carForm.model" />
        </FormItem>
        <FormItem label="排量" prop="displacement">
          <Input v-model="carForm.displacement" />
        </FormItem>
        <Form-item label="购置年份">
          <Row>
            <Col span="11">
              <Date-picker @on-change="change1" type="date"
                           value="yyyy-MM-dd" placeholder="选择日期" v-model="carForm.buyYear"></Date-picker>
            </Col>
          </Row>
        </Form-item>
        <FormItem label="牌照" prop="carNo">
          <Input v-model="carForm.carNo" />
        </FormItem>
        <FormItem label="加油卡号" prop="addOilCode">
          <Input v-model="carForm.addOilCode" />
        </FormItem>
        <FormItem label="车辆编号" prop="code">
          <Input v-model="carForm.code" />
        </FormItem>
        <FormItem label="司机" prop="userId">
          <Select v-model="carForm.userId" filterable>
            <Option :value="0">请选择</Option>
            <Option v-for="item in userList" :value="item.id" :key="item.id">{{ item.nickname }}</Option>
          </Select>
        </FormItem>
        <FormItem label="配送员" prop="followUserId">
          <Select v-model="carForm.followUserId" filterable>
            <Option :value="0" :key="0">请选择</Option>
            <Option v-for="item in driverList" :value="item.id" :key="item.id">{{ item.nickname }}</Option>
          </Select>
        </FormItem>
      </Form>
      <div slot="footer">
        <Button type="text" @click="carRole">取消</Button>
        <Button type="primary" :loading="submitLoading" @click="submitCar"
          >提交</Button
        >
      </div>
    </Modal>
    <Modal :title="modalTitle" v-model="equipmentVisible" :mask-closable="false" :width="1044">
      <Row class="operation" style="padding-bottom: 20px">
        <Button @click="addEquipment" type="primary" icon="md-add">添加设备</Button>
        <Button @click="init" icon="md-refresh">刷新</Button>
      </Row>
      <Table :loading="loading" border :columns="columns2" :data="data2" ref="table"
             sortable="custom" @on-sort-change="changeSort" @on-selection-change="changeSelect">


      </Table>
    </Modal>
    <!-- 菜单权限 -->
    <Drawer
      :title="modalTitle"
      v-model="permModalVisible"
      :mask-closable="false"
      :width="500"
      draggable
    >
      <div :style="{ maxHeight: maxHeight }" class="drawer-content">
        <div style="position: relative">
          <Tree
            ref="tree"
            :data="permData"
            show-checkbox
            :render="renderContent"
            :check-strictly="true"
          ></Tree>
          <Spin size="large" fix v-if="treeLoading"></Spin>
        </div>
      </div>
      <div class="drawer-footer br">
        <Button
          type="primary"
          :loading="submitPermLoading"
          @click="submitPermEdit"
          >提交</Button
        >
        <Button @click="selectTreeAll">全选/反选</Button>
        <Select
          v-model="openLevel"
          @on-change="changeOpen"
          style="width: 110px"
          transfer
        >
          <Option value="0">展开所有</Option>
          <Option value="1">收合所有</Option>
          <Option value="2">仅展开一级</Option>
          <Option value="3">仅展开两级</Option>
        </Select>
        <Button type="text" @click="cancelPermEdit">取消</Button>
      </div>
    </Drawer>
    <!-- 数据权限 -->
    <Modal
      :title="modalTitle"
      v-model="carModalVisible"
      :mask-closable="false"
      :width="500"
      class="depModal"
    >
      <Form :label-width="85" ref="removeForm" :model="removeForm">
        <FormItem label="移除原因" prop="removeReason">
          <Input v-model="removeForm.removeReason"/>
        </FormItem>
      </Form>
      <div v-show="dataType == 1" style="margin-top: 15px">
        <div style="position: relative">
          <Tree
            ref="depTree"
            :data="depData"
            :load-data="loadData"
            @on-toggle-expand="expandCheckDep"
            multiple
            style="margin-top: 15px"
          ></Tree>
          <Spin size="large" fix v-if="depTreeLoading"></Spin>
        </div>
      </div>
      <div slot="footer">
        <Button type="text" @click="depModalVisible = false">取消</Button>
        <Button
          type="primary"
          :loading="submitDepLoading"
          @click="submitRemove"
          >提交</Button
        >
      </div>
    </Modal>
  </div>
</template>

<script>
import {
  getAllPermissionList,
  setDefaultRole,
  editRolePerm,
  initDepartment,
  loadDepartment,
  editRoleDep,
} from "@/api/index";

import {
  getAll,
  addCar,
  getCarList,
  editCar,
  deleteCar,
  getEquipment,
  addEquipment,
  getUser,
  getDriver,
  deleteEquipment,
  getOrderEvaluate
} from "@/api/open";
import util from "@/libs/util.js";
export default {
  name: "car-manage",
  data() {
    return {
      maxHeight: 510,
      openTip: true,
      openLevel: "0",
      loading: true,
      treeLoading: true,
      depTreeLoading: true,
      submitPermLoading: false,
      submitDepLoading: false,
      searchKey: "",
      sortColumn: "createTime",
      sortType: "desc",
      modalType: 0,
      roleModalVisible: false,
      addEquipmentVisible: false,
      equipmentVisible: false,
      carModalVisible: false,
      permModalVisible: false,
      depModalVisible: false,
      modalTitle: "",
      searchForm: {
        // 搜索框初始化对象
        pageNumber: 1, // 当前页数
        pageSize: 10, // 页面大小
        sort: "sendDate", // 默认排序字段
        order: "desc", // 默认排序方式
        key: "",
      },
      carForm: {
        status : 0
      },
      type: {
        type : 0
      },
      equipmentForm: {
        status : 0
      },
      removeForm: {
        status : 1
      },
      carFormValidate: {
        name: [
          { required: true, message: "角色名称不能为空", trigger: "change" },
        ],
      },
      submitLoading: false,
      selectList: [],
      columns: [
        {
          type: "selection",
          width: 60,
          align: "center",
        },
        {
          type: "index",
          width: 60,
          align: "center",
        },
        {
          title: "商户名称",
          key: "customerName",
          minWidth: 400,
        },
        {
          title: "送货条数",
          key: "num",
          width: 160,
          sortable: true,
        },
        {
          title: "送货日期",
          key: "sendDate",
          width: 160,
          sortable: true,
        },
        {
          title: "评价星级",
          key: "level",
          width: 130,
          sortable: true,
        },
      ],
      data: [],
      data2: [],
      total: 0,
      total2: 0,
      permData: [],
      editRolePermId: "",
      selectAllFlag: false,
      depData: [],
      dataType: 0,
      carId: '',
      driverList: [],
      userList: [],
      editDepartments: [],
      buyYear:''
    };
  },

  methods: {
    change1(e){
      this.buyYear = e;
    },
    init() {
      this.getDataList();
      // 获取所有菜单权限树
    },
    renderContent(h, { root, node, data }) {
      let icon = "";
      if (data.level == 0) {
        icon = "ios-navigate";
      } else if (data.level == 1) {
        icon = "md-list-box";
      } else if (data.level == 2) {
        icon = "md-list";
      } else if (data.level == 3) {
        icon = "md-radio-button-on";
      } else {
        icon = "md-radio-button-off";
      }
      return h(
        "span",
        {
          style: {
            display: "inline-block",
            cursor: "pointer",
          },
          on: {
            click: () => {
              if (data.status == -1) {
                return;
              }
              data.checked = !data.checked;
            },
          },
        },
        [
          h("span", [
            h("Icon", {
              props: {
                type: icon,
                size: "16",
              },
              style: {
                "margin-right": "8px",
                "margin-bottom": "3px",
              },
            }),
            h("span", data.title),
          ]),
        ]
      );
    },
    changePage(v) {
      this.searchForm.pageNumber = v;
      this.getDataList();
      this.clearSelectAll();
    },
    changePageSize(v) {
      this.searchForm.pageSize = v;
      this.getDataList();
    },
    getAllUser(){
      getDriver({type:0}).then((res)=>{
        if (res.success){
          this.userList=res.result;
        }
      });
      //this.type.type=1;
      getDriver({type:1}).then((res)=>{
        if (res.success){
          this.driverList=res.result;
        }
      });
      this.type.type=0;
      console.log(this.userList);
      console.log(this.driverList);
    },
    changeSort(e) {
      this.searchForm.sort = e.key;
      this.searchForm.order = e.order;
      if (e.order == "normal") {
        this.searchForm.order = "";
      }
      this.getDataList();
    },
    getDataList() {
      this.loading = true;
      getOrderEvaluate(this.searchForm).then((res) => {
        this.loading = false;
        if (res.success) {
          this.data = res.result.records;
          this.total = res.result.total;
        }
      });
    },
    getEquipmentList(carId) {
      this.loading = true;
      this.searchForm.carId=carId;
      getEquipment(this.searchForm).then((res) => {
        this.loading = false;
        if (res.success) {
          this.data2 = res.result.records;
        }
      });
    },
    getPermList() {
      this.treeLoading = true;
      getAllPermissionList().then((res) => {
        if (res.success) {
          this.deleteDisableNode(res.result);
          this.permData = res.result;
          this.treeLoading = false;
        }
        this.treeLoading = false;
      });
    },
    // 递归标记禁用节点
    deleteDisableNode(permData) {
      let that = this;
      permData.forEach(function (e) {
        if (e.status == -1) {
          e.title = "[已禁用] " + e.title;
          e.disabled = true;
        }
        if (e.children && e.children.length > 0) {
          that.deleteDisableNode(e.children);
        }
      });
    },
    carRole() {
      this.roleModalVisible = false;
    },
    submitCar() {
      if(this.carForm.userId==undefined || this.carForm.userId==0){
        this.carForm.userId="";
      }
      if(this.carForm.followUserId==undefined || this.carForm.followUserId==0){
        this.carForm.followUserId="";
      }
      this.carForm.buyYear = this.buyYear;
      this.$refs.carForm.validate((valid) => {
        if (valid) {
          if (this.modalType == 0) {
            // 添加
            this.submitLoading = true;
            addCar(this.carForm).then((res) => {
              this.submitLoading = false;
              if (res.success) {
                this.$Message.success("操作成功");
                this.getDataList();
                this.roleModalVisible = false;
              }
            });
          } else {
            this.submitLoading = true;
            editCar(this.carForm).then((res) => {
              this.submitLoading = false;
              if (res.success) {
                this.$Message.success("操作成功");
                this.getDataList();
                this.roleModalVisible = false;
              }
            });
          }
        }
      });
    },
    submitEquipment() {
      this.$refs.equipmentForm.validate((valid) => {
        this.equipmentForm.carId = this.carId;
        if (valid) {
          if (this.modalType == 0) {
            // 添加
            this.submitLoading = true;
            addEquipment(this.equipmentForm).then((res) => {
              this.submitLoading = false;
              if (res.success) {
                this.$Message.success("操作成功");
                this.getEquipmentList(this.carId);
                this.addEquipmentVisible = false;
                this.getEquipmentList(this.carId);
              }
            });
          } else {
            this.submitLoading = true;
            addEquipment(this.equipmentForm).then((res) => {
              this.submitLoading = false;
              if (res.success) {
                this.$Message.success("操作成功");
                this.getEquipmentList(this.carId);
                this.addEquipmentVisible = false;
              }
            });
          }
        }

      });
    },
    submitRemove(){
      this.$refs.removeForm.validate((valid) => {
        if (valid) {
            this.submitLoading = true;
            editCar(this.removeForm).then((res) => {
              this.submitLoading = false;
              if (res.success) {
                this.$Message.success("操作成功");
                this.getDataList();
                this.carModalVisible = false;
              }
            });
        }
      });
    },
    equipment(row) {
      this.carId = row.id
      this.getEquipmentList(row.id);
      this.modalType = 0;
      this.modalTitle = "设备信息";
      this.$refs.carForm.resetFields();
      delete this.carForm.id;
      this.equipmentVisible = true;
    },
    addCar() {
      this.carForm={};
      this.getAllUser();
      this.modalType = 0;
      this.modalTitle = "添加车辆";
      this.$refs.carForm.resetFields();
      delete this.carForm.id;
      this.roleModalVisible = true;
    },
    addEquipment() {
      this.equipmentForm={};
      this.modalType = 0;
      this.modalTitle = "添加设备";
      this.$refs.carForm.resetFields();
      delete this.carForm.id;
      this.addEquipmentVisible = true;
    },
    edit(v) {
      this.getAllUser();
      this.buyYear = v.buyYear;
      this.modalType = 1;
      this.modalTitle = "编辑";
      this.$refs.carForm.resetFields();
      // 转换null为""
      for (let attr in v) {
        if (v[attr] == null) {
          v[attr] = "";
        }
      }
      let str = JSON.stringify(v);
      let roleInfo = JSON.parse(str);
      this.carForm = roleInfo;
      this.roleModalVisible = true;
    },
    editEquipment(v) {
      this.modalType = 1;
      this.modalTitle = "编辑设备";
      this.$refs.equipmentForm.resetFields();
      // 转换null为""
      for (let attr in v) {
        if (v[attr] == null) {
          v[attr] = "";
        }
      }
      let str = JSON.stringify(v);
      let roleInfo = JSON.parse(str);
      this.equipmentForm = roleInfo;
      this.addEquipmentVisible = true;
    },
    removeCar(v) {
      this.dataType = 0;
      this.modalTitle = "移除车辆";
      this.$refs.carForm.resetFields();
      // 转换null为""
      for (let attr in v) {
        if (v[attr] == null) {
          v[attr] = "";
        }
      }
      let str = JSON.stringify(v);
      let roleInfo = JSON.parse(str);
      roleInfo.status=1
      this.removeForm = roleInfo;
      this.carModalVisible = true;

    },
    remove(v) {
      this.$Modal.confirm({
        title: "确认删除",
        content: "您确认要删除吗 ",
        loading: true,
        onOk: () => {
          deleteCar({ ids: v.id }).then((res) => {
            this.$Modal.remove();
            if (res.success) {
              this.clearSelectAll();
              this.$Message.success("删除成功");
              this.getDataList();
            }
          });
        },
      });
    },
    removeEquipment(v) {
      this.$Modal.confirm({
        title: "确认删除",
        content: "您确认要删除吗 ",
        loading: true,
        onOk: () => {
          deleteEquipment({ ids: v.id }).then((res) => {
            this.$Modal.remove();
            if (res.success) {
              this.clearSelectAll();
              this.$Message.success("删除成功");
              this.getEquipmentList(this.carId);
            }
          });
        },
      });
    },
    setDefault(v) {
      this.loading = true;
      let params = {
        id: v.id,
        isDefault: true,
      };
      setDefaultRole(params).then((res) => {
        this.loading = false;
        if (res.success) {
          this.$Message.success("操作成功");
          this.getDataList();
        }
      });
    },
    cancelDefault(v) {
      this.loading = true;
      let params = {
        id: v.id,
        isDefault: false,
      };
      setDefaultRole(params).then((res) => {
        this.loading = false;
        if (res.success) {
          this.$Message.success("操作成功");
          this.getDataList();
        }
      });
    },
    clearSelectAll() {
      this.$refs.table.selectAll(false);
    },
    changeSelect(e) {
      this.selectList = e;
    },
    delAll() {
      if (this.selectList.length <= 0) {
        this.$Message.warning("您还未选择要删除的数据");
        return;
      }
      this.$Modal.confirm({
        title: "确认删除",
        content: "您确认要删除所选的 " + this.selectList.length + " 条数据?",
        loading: true,
        onOk: () => {
          let ids = "";
          this.selectList.forEach(function (e) {
            ids += e.id + ",";
          });
          ids = ids.substring(0, ids.length - 1);
          deleteCar({ ids: ids }).then((res) => {
            this.$Modal.remove();
            if (res.success) {
              this.$Message.success("删除成功");
              this.clearSelectAll();
              this.getDataList();
            }
          });
        },
      });
    },
    editPerm(v) {
      this.editRolePermId = v.id;
      this.modalTitle = "分配 " + v.name + " 的菜单权限";
      // 匹配勾选
      let rolePerms = v.permissions;
      if (this.treeLoading) {
        this.$Message.warning("菜单权限数据加载中，请稍后点击查看");
        return;
      }
      // 递归判断子节点
      this.checkPermTree(this.permData, rolePerms);
      this.permModalVisible = true;
    },
    // 递归判断子节点
    checkPermTree(permData, rolePerms) {
      let that = this;
      permData.forEach(function (p) {
        if (that.hasPerm(p, rolePerms) && p.status != -1) {
          p.checked = true;
        } else {
          p.checked = false;
        }
        if (p.children && p.children.length > 0) {
          that.checkPermTree(p.children, rolePerms);
        }
      });
    },
    // 判断角色拥有的权限节点勾选
    hasPerm(p, rolePerms) {
      let flag = false;
      for (let i = 0; i < rolePerms.length; i++) {
        if (p.id == rolePerms[i].permissionId) {
          flag = true;
          break;
        }
      }
      if (flag) {
        return true;
      }
      return false;
    },
    // 全选反选
    selectTreeAll() {
      this.selectAllFlag = !this.selectAllFlag;
      let select = this.selectAllFlag;
      this.selectedTreeAll(this.permData, select);
    },
    // 递归全选节点
    selectedTreeAll(permData, select) {
      let that = this;
      permData.forEach(function (e) {
        e.checked = select;
        if (e.children && e.children.length > 0) {
          that.selectedTreeAll(e.children, select);
        }
      });
    },
    submitPermEdit() {
      this.submitPermLoading = true;
      let permIds = "";
      let selectedNodes = this.$refs.tree.getCheckedNodes();
      selectedNodes.forEach(function (e) {
        permIds += e.id + ",";
      });
      permIds = permIds.substring(0, permIds.length - 1);
      editRolePerm({
        roleId: this.editRolePermId,
        permIds: permIds,
      }).then((res) => {
        this.submitPermLoading = false;
        if (res.success) {
          this.$Message.success("操作成功");
          // 标记重新获取菜单数据
          this.$store.commit("setAdded", false);
          util.initRouter(this);
          this.getDataList();
          this.permModalVisible = false;
        }
      });
    },
    cancelPermEdit() {
      this.permModalVisible = false;
    },
    loadData(item, callback) {
      loadDepartment(item.id, { openDataFilter: false }).then((res) => {
        if (res.success) {
          res.result.forEach(function (e) {
            e.selected = false;
            if (e.isParent) {
              e.loading = false;
              e.children = [];
            }
            if (e.status == -1) {
              e.title = "[已禁用] " + e.title;
              e.disabled = true;
            }
          });
          callback(res.result);
        }
      });
    },
    expandCheckDep(v) {
      // 判断展开子节点
      this.checkDepTree(v.children, this.editDepartments);
    },
    // 判断子节点
    checkDepTree(depData, roleDepIds) {
      let that = this;
      depData.forEach(function (p) {
        if (that.hasDepPerm(p, roleDepIds)) {
          p.selected = true;
        } else {
          p.selected = false;
        }
      });
    },
    // 判断角色拥有的权限节点勾选
    hasDepPerm(p, roleDepIds) {
      let flag = false;
      for (let i = 0; i < roleDepIds.length; i++) {
        if (p.id == roleDepIds[i].departmentId) {
          flag = true;
          break;
        }
      }
      if (flag) {
        return true;
      }
      return false;
    },
    submitDepEdit() {
      let depIds = "";
      if (this.dataType == 1) {
        let selectedNodes = this.$refs.depTree.getSelectedNodes();
        selectedNodes.forEach(function (e) {
          depIds += e.id + ",";
        });
        depIds = depIds.substring(0, depIds.length - 1);
      }
      this.submitDepLoading = true;
      editRoleDep({
        roleId: this.editRolePermId,
        dataType: this.dataType,
        depIds: depIds,
      }).then((res) => {
        this.submitDepLoading = false;
        if (res.success) {
          this.$Message.success("操作成功");
          this.getDataList();
          this.depModalVisible = false;
        }
      });
    },
    changeOpen(v) {
      if (v == "0") {
        this.permData.forEach((e) => {
          e.expand = true;
          if (e.children && e.children.length > 0) {
            e.children.forEach((c) => {
              c.expand = true;
              if (c.children && c.children.length > 0) {
                c.children.forEach(function (b) {
                  b.expand = true;
                });
              }
            });
          }
        });
      } else if (v == "1") {
        this.permData.forEach((e) => {
          e.expand = false;
          if (e.children && e.children.length > 0) {
            e.children.forEach((c) => {
              c.expand = false;
              if (c.children && c.children.length > 0) {
                c.children.forEach(function (b) {
                  b.expand = false;
                });
              }
            });
          }
        });
      } else if (v == "2") {
        this.permData.forEach((e) => {
          e.expand = true;
          if (e.children && e.children.length > 0) {
            e.children.forEach((c) => {
              c.expand = false;
              if (c.children && c.children.length > 0) {
                c.children.forEach(function (b) {
                  b.expand = false;
                });
              }
            });
          }
        });
      } else if (v == "3") {
        this.permData.forEach((e) => {
          e.expand = true;
          if (e.children && e.children.length > 0) {
            e.children.forEach((c) => {
              c.expand = true;
              if (c.children && c.children.length > 0) {
                c.children.forEach(function (b) {
                  b.expand = false;
                });
              }
            });
          }
        });
      }
    },
  },
  mounted() {
    this.maxHeight = Number(document.documentElement.clientHeight - 121) + "px";
    this.init();
  },
};
</script>